@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.11 96/05/13 08:04:44 abe Exp $
+ * $Id: dlsof.h,v 1.9 98/03/10 16:23:55 abe Exp $
  */
 
 
@@ -43,16 +43,17 @@
 #include <dirent.h>
 #include <setjmp.h>
 #include <unistd.h>
-#include <sys/domain.h>
 
 # if	!defined(_KERNEL)
 #define _KERNEL	1
 # endif
 
+#include <sys/vnode.h>
 #include <sys/file.h>
 #include <procinfo.h>
 #define p_pid	pi_pid
 #define	p_pgrp	pi_pgrp
+#define	p_ppid	pi_ppid
 #define p_stat	pi_stat
 #define p_uid	pi_uid
 #undef	sleep
@@ -70,18 +71,32 @@
 #include <net/route.h>
 #include <net/raw_cb.h>
 
-# if	_AIXV>=4100
+# if	AIXV>=4100
 #include <netinet/ip.h>
-# endif	/* _AIXV>=4100 */
+# endif	/* AIXV>=4100 */
 
 #include <netinet/in_pcb.h>
+#include <netinet/ip_var.h>
+#include <netinet/tcp.h>
+#include <netinet/tcpip.h>
+#include <netinet/tcp_fsm.h>
+#include <netinet/tcp_timer.h>
+#include <netinet/tcp_var.h>
 #include <sys/vattr.h>
+#include <sys/statfs.h>
+
+#include <rpc/rpc.h>
+#include <rpc/pmap_prot.h>
+
+# if	defined(HAS_AFS)
+#define	__XDR_INCLUDE__
+# endif	/* defined(HAS_AFS) */
+
 #include <sys/vfs.h>
 #include <sys/vmount.h>
-#include <sys/vnode.h>
 
-# if	_AIXV>=4100
-#  if	_AIXV>=4110
+# if	AIXV>=4100
+#  if	AIXV>=4110
 #undef	u
 #undef	u_comm
 #undef	u_cdir
@@ -89,7 +104,7 @@
 #undef	u_maxofile
 #undef	u_ufd
 #undef	u_loader
-#  endif	/* _AIXV>=4110 */
+#  endif	/* AIXV>=4110 */
 
 #define	u_comm		U_comm
 #define	u_cdir		U_cdir
@@ -97,13 +112,15 @@
 #define	u_maxofile	U_maxofile
 #define	u_ufd		U_ufd
 #define	u_loader	U_loader
-# endif	/* _AIXV>=4100 */
+# endif	/* AIXV>=4100 */
 
+# if	defined(HAS_NFS)
 #include <nfs/rnode.h>
+# endif	/* defined(HAS_NFS) */
 
-#  if	_AIXV>=3200
+#  if	AIXV>=3200
 #include <sys/specnode.h>
-#  endif	/* _AIXV>=3200 */
+#  endif	/* AIXV>=3200 */
 
 /*
  * AIX doesn't supply cdrnode.h.
@@ -133,14 +150,14 @@ struct le {
 	uint dummy3;
 	struct file *fp;		/* file table entry pointer */
 
-# if	_AIXV>=4110
+# if	AIXV>=4110
 	int ft;				/* file type indicator */
 	unsigned dummy4;
 	char *dummy5;
 	unsigned dummy6;
 	char *dummy7[3];
 	char *nm;			/* name */
-# endif	/* _AIXV>=4110 */
+# endif	/* AIXV>=4110 */
 
 };
 
@@ -187,7 +204,7 @@ typedef struct afs_lock afs_rwlock_t;
 #  endif	/* !defined(MNT_AFS) */
 # endif	/* defined(HAS_AFS) */
 
-#define	COMP_P		void
+#define	COMP_P		const void
 #define DEVINCR		1024	/* device table malloc() increment */
 #define	KA_T		off_t
 #define KMEM		"/dev/kmem"
@@ -196,13 +213,20 @@ typedef struct afs_lock afs_rwlock_t;
 #define MALLOC_S	unsigned
 #define	N_UNIX		"/unix"
 #define PROCSIZE	sizeof(struct procinfo)
-#define QSORT_P		char
+#define QSORT_P		void
 #define	READLEN_T	unsigned
 #define STRNCPY_L	size_t
+
+# if	AIXV>=4200
+#define	SZOFFTYPE	unsigned long long
+				/* size and offset type definition */
+#define	SZOFFPSPEC	"ll"	/* SZOFFTYPE print specification modifier */
+# endif	/* AIXV>=4200 */
+
 #define U_SIZE		sizeof(struct user)
 
 
-# if	_AIXV>=4110
+# if	AIXV>=4110
 /*
  * readx() definitions for AIX 4.1.1 and above.
  */
@@ -213,7 +237,7 @@ typedef struct afs_lock afs_rwlock_t;
 #define	LIBNMLN		40			/* maximum library table name
 						 * length */
 #define	RDXMASK		0x0fffffff		/* kreadx() address mask */
-# endif	/* _AIXV>=4110 */
+# endif	/* AIXV>=4110 */
 
 
 /*
@@ -224,6 +248,25 @@ typedef struct afs_lock afs_rwlock_t;
 #define	X_NL_NUM	1
 
 
+/*
+ * Define for ckfa.c
+ */
+
+#define	CKFA_MPXCHAN	1
+
+
+/*
+ * Definitions for dvch.c
+ */
+
+#if	AIXV>=4140
+#define	DCACHE_CLONE	rw_clone_sect	/* clone function for read_dcache */
+#define	DCACHE_CLR	clr_sect	/* function to clear clone and
+					 * pseudo caches when reading the
+					 * device cache file fails */
+#endif	/* AIXV>=4140 */
+
+
 # if	defined(HAS_AFS)
 /*
  * AFS name list (AFSnl[]) indexes
@@ -235,21 +278,19 @@ typedef struct afs_lock afs_rwlock_t;
 # endif	/* defined(HAS_AFS) */
 
 
-# if	_AIXV>=4140
+# if	AIXV>=4140
 /*
  * Local clone information
  */
 
 struct clone {
-	unsigned long ino;		/* inode number */
-	char *nm;			/* device name */
-	dev_t rdev;			/* device number */
+	struct l_dev cd;		/* device, inode, name, verify status */
 	struct clone *next;		/* next entry */
 };
 extern struct clone *Clone;
 extern int CloneMaj;
 extern int ClonePtc;
-#endif	/* _AIXV>=4140 */
+#endif	/* AIXV>=4140 */
 
 
 /*
@@ -257,7 +298,7 @@ extern int ClonePtc;
  */
 
 struct l_vfs {
-	struct vfs *addr;		/* kernel address */
+	KA_T addr;			/* kernel address */
 	dev_t dev;			/* device */
 	char *dir;			/* mounted directory */
 	char *fsname;			/* file system name */
@@ -273,13 +314,17 @@ extern struct l_vfs *Lvfs;
  */
 
 struct mounts {
-        dev_t dev;              	/* st_dev */
-        char *dir;              	/* directory */
-        char *fsname;           	/* file system */
-	ino_t inode;			/* st_ino */
-	u_short mode;			/* st_mode */
+        char *dir;              	/* directory (mounted on) */
+	char *fsname;           	/* file system
+					 * (symbolic links unresolved) */
+	char *fsnmres;           	/* file system
+					 * (symbolic links resolved) */
+        dev_t dev;              	/* directory st_dev */
+	dev_t rdev;			/* directory st_rdev */
+	ino_t inode;			/* directory st_ino */
+	u_short mode;			/* directory st_mode */
+	u_short fs_mode;		/* file system st_mode */
         struct mounts *next;    	/* forward link */
-	dev_t rdev;			/* st_rdev */
 };
 extern struct mounts *Mtab;
 
@@ -315,10 +360,11 @@ extern struct nlist AFSnl[];	/* AFS kernel symbol name list table */
 extern char *AFSApath;		/* alternate AFS name list path (from -a) */
 #  endif	/* defined(HASAOPT) */
 
-extern struct vfs *AFSVfsp;	/* AFS struct vfs kernel pointer */
+KA_T AFSVfsp;			/* AFS struct vfs kernel pointer */
 # endif	/* defined(HAS_AFS) */
 
-extern int Kmem;
-extern int Mem;
+extern int Kd;
+extern int Km;
+extern struct nlist Nl[];
 
 #endif	/* AIX_LSOF_H */
