@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.16 96/04/05 09:48:26 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.3 98/03/06 08:04:35 abe Exp $";
 #endif
 
 
@@ -42,9 +42,9 @@ static char *rcsid = "$Id: dproc.c,v 1.16 96/04/05 09:48:26 abe Exp $";
 _PROTOTYPE(static void get_kernel_access,(void));
 _PROTOTYPE(static struct le *getle,(long a, long sid, char **err));
 
-#if	_AIXV>=4110
+#if	AIXV>=4110
 _PROTOTYPE(static void getlenm,(struct le *le));
-#endif	/* _AIXV>=4110 */
+#endif	/* AIXV>=4110 */
 
 _PROTOTYPE(static void process_text,(unsigned long sid));
 
@@ -57,11 +57,11 @@ static int Np = 0;			/* number of processes */
 static struct procinfo *P = NULL;	/* the process table */
 static struct user *Up;			/* user structure */
 
-#if	_AIXV>=4110
+#if	AIXV>=4110
 static unsigned long Soff;		/* shared library VM offset */
 int Soff_stat = 0;			/* Soff-available status */
 static unsigned long Uoff;		/* user area VM offset */
-#endif	/* _AIXV>=4110 */
+#endif	/* AIXV>=4110 */
 
 
 /*
@@ -92,11 +92,10 @@ gather_proc_info()
 		if ((P = (struct procinfo *)realloc((MALLOC_P *)P,
 		    (size_t) (Np * PROCSIZE))) == NULL) {
 			(void) fprintf(stderr,
-				"%s: no space for %ld procinfo's\n", Pn, Np);
+				"%s: no space for %d procinfo's\n", Pn, Np);
 			Exit(1);
 		}
 	}
-	iuidcache(Np);
 /*
  * Loop through processes.
  */
@@ -111,11 +110,11 @@ gather_proc_info()
 	 *
 	 * If AIX version is below 4.1.1, use getuser().
 	 *
-	 * If AIX version is 4.1.1: if readx() is disabled, use getuser();
-	 * if readx() is enabled, use readx().
+	 * If AIX version is 4.1.1 or above: if readx() is disabled, use
+	 * getuser(); if readx() is enabled, use readx().
 	 */
 
-#if	_AIXV>=4110
+#if	AIXV>=4110
 		if (Fxopt
 		&&  kreadx(Uoff, (char *)Up, U_SIZE, p->pi_adspace) == 0)
 			i = 1;
@@ -125,25 +124,25 @@ gather_proc_info()
 			if (getuser(p, PROCSIZE, Up, U_SIZE) != 0)
 				continue;
 		}
-#else	/* _AIXV<4110 */
+#else	/* AIXV<4110 */
 		if (getuser(p, PROCSIZE, Up, U_SIZE) != 0)
 			continue;
-#endif	/* _AIXV>=4110 */
+#endif	/* AIXV>=4110 */
 
 	/*
 	 * Allocate a local process structure and start filling it.
 	 */
 		if (is_cmd_excl(Up->u_comm, &pss, &sf))
 			continue;
-		alloc_lproc(p->p_pid, (int)p->p_pgrp, (UID_ARG)p->p_uid,
-			Up->u_comm, (int)pss, (int)sf);
-		Plf = NULL;
+		alloc_lproc(p->p_pid, (int)p->p_pgrp, (int)p->p_ppid,
+			(UID_ARG)p->p_uid, Up->u_comm, (int)pss, (int)sf);
+		Plf = (struct lfile *)NULL;
 	/*
 	 * Save current working directory information.
 	 */
 		if (Up->u_cdir) {
 			alloc_lfile(CWD, -1);
-			process_node((caddr_t)Up->u_cdir);
+			process_node((KA_T)Up->u_cdir);
 			if (Lf->sf)
 				link_lfile();
 		}
@@ -152,22 +151,22 @@ gather_proc_info()
 	 */
 		if (Up->u_rdir) {
 			alloc_lfile(RTD, -1);
-			process_node((caddr_t)Up->u_rdir);
+			process_node((KA_T)Up->u_rdir);
 			if (Lf->sf)
 				link_lfile();
 		}
 
-#if	_AIXV<4100
+#if	AIXV<4100
 	/*
 	 * Save parent directory information.
 	 */
 		if (Up->u_pdir) {
 			alloc_lfile("  pd", -1);
-			process_node((caddr_t)Up->u_pdir);
+			process_node((KA_T)Up->u_pdir);
 			if (Lf->sf)
 				link_lfile();
 		}
-#endif	/* _AIXV<4100 */
+#endif	/* AIXV<4100 */
 
 	/*
 	 * Save information on text files.
@@ -205,7 +204,7 @@ get_kernel_access()
 /*
  * Access /dev/mem.
  */
-	if ((Mem = open("/dev/mem", O_RDONLY, 0)) < 0) {
+	if ((Km = open("/dev/mem", O_RDONLY, 0)) < 0) {
 		(void) fprintf(stderr, "%s: can't open /dev/mem: %s\n",
 			Pn, strerror(errno));
 		Exit(1);
@@ -229,7 +228,7 @@ get_kernel_access()
 /*
  * Access kernel memory file.
  */
-	if ((Kmem = open(Memory ? Memory : KMEM, O_RDONLY, 0)) < 0) {
+	if ((Kd = open(Memory ? Memory : KMEM, O_RDONLY, 0)) < 0) {
 		(void) fprintf(stderr, "%s: can't open %s: %s\n", Pn,
 			Memory ? Memory : KMEM, strerror(errno));
 		Exit(1);
@@ -257,7 +256,7 @@ get_kernel_access()
 	(void) knlist(&AFSnl, X_AFSNL_NUM, sizeof(struct nlist));
 #endif	/* defined(HAS_AFS) */
 
-#if	_AIXV>=4110
+#if	AIXV>=4110
 /*
  * Get user area and shared library VM offsets for AIX 4.1.1 and above.
  */
@@ -279,7 +278,7 @@ get_kernel_access()
 		ub = (struct ublock *)Nl[X_UADDR].n_value;
 		Uoff = (unsigned long)((int)&ub->ub_user & RDXMASK);
 	}
-#endif	/* _AIXV>=4110 */
+#endif	/* AIXV>=4110 */
 
 }
 
@@ -296,25 +295,25 @@ getle(a, sid, err)
 {
 	static struct le le;
 
-#if	_AIXV<4110
+#if	AIXV<4110
 	if (a < Nl[X_UADDR].n_value) {
 		*err = "address too small";
 		return(NULL);
 	}
 	if (((char *)a + sizeof(le)) <= ((char *)Nl[X_UADDR].n_value + U_SIZE))
 		return((struct le *)((char *)Up + a - Nl[X_UADDR].n_value));
-#endif	/* _AIXV<4110 */
+#endif	/* AIXV<4110 */
 
 	if ( ! Fxopt) {
 		*err = "readx() disabled for Stale Segment ID bug (see -X)";
 		return(NULL);
 	}
 
-#if	_AIXV>=4110
+#if	AIXV>=4110
 	if (kreadx((off_t)(a & RDXMASK), (char *)&le, sizeof(le), sid) == 0)
-#else	/* _AIXV<4110 */
+#else	/* AIXV<4110 */
 	if (kreadx((off_t)a, (char *)&le, sizeof(le), sid) == 0)
-#endif	/* _AIXV>=4110 */
+#endif	/* AIXV>=4110 */
 
 		return(&le);
 	*err = "can't readx()";
@@ -322,7 +321,7 @@ getle(a, sid, err)
 }
 
 
-#if	_AIXV>=4110
+#if	AIXV>=4110
 /*
  * getlenm() - get loader entry file name for AIX 4.1.1 and above
  */
@@ -346,7 +345,7 @@ getlenm(le)
 			enter_nm(buf);
 	}
 }
-#endif	/* _AIXV>=4110 */
+#endif	/* AIXV>=4110 */
 
 
 
@@ -373,9 +372,9 @@ kread(addr, buf, len)
 {
 	int br;
 
-	if (lseek(Kmem, addr, L_SET) == (off_t)-1L)
+	if (lseek(Kd, addr, L_SET) == (off_t)-1L)
 		return(-1);
-	br = read(Kmem, buf, len);
+	br = read(Kd, buf, len);
 	return((br == len) ? 0 : 1);
 }
 
@@ -393,9 +392,9 @@ kreadx(addr, buf, len, sid)
 {
 	int br;
 
-	if (lseek(Mem, addr, L_SET) == (off_t)-1)
+	if (lseek(Km, addr, L_SET) == (off_t)-1)
 		return(1);
-	br = readx(Mem, buf, len, sid);
+	br = readx(Km, buf, len, sid);
 	return (br == len ? 0 : 1);
 }
 
@@ -421,13 +420,13 @@ process_text(sid)
 		alloc_lfile(" txt", -1);
 		if ((le = getle(ll, sid, &err)) != NULL) {
 			if (le->fp) {
-				process_file((struct file *)le->fp);
+				process_file((KA_T)le->fp);
 				if (Lf->sf) {
 
-#if	_AIXV>=4110
+#if	AIXV>=4110
 					if (Lf->nm == NULL || Lf->nm[0] == '\0')
 						getlenm(le);
-#endif	/* _AIXV>=4110 */
+#endif	/* AIXV>=4110 */
 
 					link_lfile();
 				}
@@ -493,13 +492,13 @@ process_text(sid)
 	/*
 	 * Save the loader entry.
 	 */
-		process_file((struct file *)le->fp);
+		process_file((KA_T)le->fp);
 		if (Lf->sf) {
 
-#if	_AIXV>=4110
+#if	AIXV>=4110
 			if (Lf->nm == NULL || Lf->nm[0] == '\0')
 				getlenm(le);
-#endif	/* _AIXV>=4110 */
+#endif	/* AIXV>=4110 */
 
 			link_lfile();
 			i++;
