@@ -33,10 +33,10 @@
 
 
 /*
- * $Id: dproto.h,v 1.1 96/01/11 14:51:41 abe Exp $
+ * $Id: dproto.h,v 1.2 98/03/06 08:07:46 abe Exp $
  */
 
 
 _PROTOTYPE(extern int is_file_named,(char *p, enum vtype ty));
-_PROTOTYPE(extern struct l_vfs *readvfs,(struct mount *vm));
-_PROTOTYPE(extern void process_socket,(caddr_t sa));
+_PROTOTYPE(extern struct l_vfs *readvfs,(KA_T vm));
+_PROTOTYPE(extern void process_socket,(KA_T sa));
