@@ -31,14 +31,26 @@
 
 
 /*
- * $Id: machine.h,v 1.26 96/02/21 08:06:36 abe Exp $
+ * $Id: machine.h,v 1.12 98/02/16 19:48:44 abe Exp $
  */
 
 
+#if	!defined(MACHINE_H)
+#define	MACHINE_H	1
+
+
 #include <sys/types.h>
 #include <sys/param.h>
 
 
+/*
+ * GET_MAX_FD is defined for those dialects that provide a function other than
+ * getdtablesize() to obtain the maximum file descriptor number plus one.
+ */
+
+/* #define	GET_MAX_FD	?	*/
+
+
 /*
  * HASAOPT is defined for those dialects that have AFS support; it specifies
  * that the default path to an alternate AFS kernel name list file may be
@@ -48,6 +60,14 @@
 /* #define	HASAOPT		1 */
 
 
+/*
+ * HASBLKDEV is defined for those dialects that want block device information
+ * recorded in BDevtp[].
+ */
+
+#define	HASBLKDEV	1
+
+
 /*
  * HASDCACHE is defined for those dialects that support a device cache
  * file.
@@ -117,7 +137,8 @@
 
 
 /*
- * HASINODE is defined for those dialects that have inodes.
+ * HASINODE is defined for those dialects that have inodes and wish to
+ * use readinode() from node.c.
  */
 
 #define	HASINODE	1
@@ -191,6 +212,19 @@
 #define	HASNLIST	1
 
 
+/*
+ * HASPIPEFN is defined for those dialects that have a special function to
+ * process DTYPE_PIPE file structure entries.  Its value is the name of the
+ * function.
+ *
+ * NOTE: don't forget to define a prototype for this function in dproto.h.
+ */
+
+# if	FREEBSDV>=220
+#define	HASPIPEFN	process_pipe
+# endif	/* FREEBSDV>=220 */
+
+
 /*
  * HASPIPENODE is defined for those dialects that have pipe nodes.
  */
@@ -198,9 +232,70 @@
 /* #define	HASPIPENODE	1 */
 
 
+/*
+ * HASPMAPENABLED is defined when the reporting of portmapper registration
+ * info is enabled by default.
+ */
+
+/* #define	HASPMAPENABLED	1 */
+
+
+/*
+ * HASPPID is defined for those dialects that support identification of
+ * the parent process IDentifier (PPID) of a process.
+ */
+
+# if	FREEBSDV>=200
+#define	HASPPID		1
+# endif	/* FREEBSDV>=200 */
+
+
+/*
+ * HASPRINTDEV, HASPRINTINO, HASPRINTNM, HASPRINTOFF, and HASPRINTSZ
+ * define private dialect-specific functions for printing DEVice numbers,
+ * INOde numbers, NaMes, file OFFsets, and file SiZes.  The functions are
+ * called from print_file().
+ */
+
+/* #define	HASPRINTDEV	print_dev	*/
+/* #define	HASPRINTINO	print_ino	*/
+/* #define	HASPRINTNM	print_nm	*/
+/* #define	HASPRINTOFF	print_off	*/
+/* #define	HASPRINTSZ	print_sz	*/
+
+
+/*
+ * HASPRIVFILETYPE and PRIVFILETYPE are defined for dialects that have a
+ * file structure type that isn't defined by a DTYPE_* symbol.  They are
+ * used in lib/prfp.c to select the type's processing.
+ *
+ * PRIVFILETYPE is the definition of the f_type value in the file struct.
+ *
+ * HASPRIVFILETYPE is the name of the processing function.
+ */
+
+/* #define	HASPRIVFILETYPE	process_shmf	*/
+/* #define	PRIVFILETYPE	??	*/
+
+
+/*
+ * HASPRIVNMCACHE is defined for dialects that have a private method for
+ * printing cached NAME column values for some files.  HASPRIVNAMECACHE
+ * is defined to be the name of the function.
+ *
+ * The function takes one argument, a struct lfile pointer to the file, and
+ * returns non-zero if it prints a name to stdout.
+ */
+
+/* #define	HASPRIVNMCACHE	<function name>	*/
+
+
 /*
  * HASPROCFS is defined for those dialects that have a proc file system --
- * usually /proc and usually in SYSV4 derivatives.
+ * usually /proc and usually in SYSV4 derivatives.  For FreeBSD 2.0 and
+ * above the Configure script defines HASPROCFS when it can find
+ * /usr/src/sys/miscfs/procfs/procfs.h; below 2.0, Configure always defines
+ * HASPROCFS.
  *
  * HASFSTYPE is defined for those systems that have a file system type
  * string, st_fstype, in the stat() buffer.
@@ -211,32 +306,22 @@
  * definition and the providing of an fstype element in the local mounts
  * structure (defined in dlsof.h).
  *
- * The HASPROCFS definition may be accompanied by the HASPINFO definition.
- * HASPINFO names the subdirectory of HASPROCFS that contains read-only
- * information (typically /pinfo).
- *
  * The HASPROCFS definition may be accompanied by the HASPINODEN definition.
  * HASPINODEN specifies that searching for files in HASPROCFS is to be done
  * by inode number.
  */
 
-#define		HASPROCFS	"proc"
+# if	defined(HASPROCFS)
+#undef	HASPROCFS
+#define	HASPROCFS	"proc"
+# endif	/* defined(HASPROCFS) */
+
+/* #define		HASPROCFS	"proc" */
 /* #define		HASFSTYPE	1 */
-/* #define		HASPINFO	"/pinfo" */
 
-#if	_FREEBSDV>=200
-#define	HASPINODEN
-#endif	/* _FREEBSDV>=200 */
-
-
-/*
- * HASPWSTAYOPEN is defined for those dialects that have a method to hold
- * the password data base open between searches.  Setting this definition
- * implies the availability of a dialect-specific pw_stay_open() function
- * to implement the method.
- */
-
-/* #define	HASPWSTAYOPEN	1 */
+# if	FREEBSDV>=200
+#define	HASPINODEN	1
+# endif	/* FREEBSDV>=200 */
 
 
 /*
@@ -270,6 +355,22 @@
 /* #define	HASSTREAMS	1 */
 
 
+/*
+ * HASTCPTPIQ is defined for dialects where it is possible to report the
+ * TCP/TPI Recv-Q and Send-Q values produced by netstat.
+ */
+
+#define	HASTCPTPIQ	1
+
+
+/*
+ * HASTCPTPIW is defined for dialects where it is possible to report the
+ * TCP/TPI send and receive window sizes produced by netstat.
+ */
+
+/* #define	HASTCPTPIW	1 */
+
+
 /*
  * HASTMPNODE is defined for those dialects that have tmpnodes.
  */
@@ -305,6 +406,35 @@
 #define	UID_ARG	int
 
 
+/*
+ * Each USE_LIB_<function_name> is defined for dialects that use the
+ * <function_name> in the lsof library.
+ *
+ * Note: other definitions and operations may be required to condition the
+ * library function source code.  They may be found in the dialect dlsof.h
+ * header files.
+ */
+
+/* #define	USE_LIB_COMPLETEVFS		1	   cvfs.c */
+#define	USE_LIB_FIND_CH_INO			1	/* fino.c */
+#define	USE_LIB_IS_FILE_NAMED			1	/* isfn.c */
+#define	USE_LIB_LKUPDEV				1	/* lkud.c */
+#define	USE_LIB_PRINTCHDEVNAME			1	/* pdvn.c */
+#define	USE_LIB_PROCESS_FILE			1	/* prfp.c */
+#define	USE_LIB_PRINT_TCPTPI			1	/* ptti.c */
+#define	USE_LIB_READDEV				1	/* rdev.c */
+/* #define	USE_LIB_READMNT			1	   rmnt.c */
+/* #define	USE_LIB_READVFS			1	   rvfs.c */
+
+# if	FREEBSDV<210
+#define	USE_LIB_RNAM				1	/* rnam.c */
+# else	/* FREEBSDV>=210 */
+#define	USE_LIB_RNMH				1	/* rnmh.c */
+# endif	/* FREEBSDV<210 */
+
+/* #define	USE_LIB_RNCH			1	   rnch.c */
+
+
 /*
  * WARNDEVACCESS is defined for those dialects that should issue a warning
  * when lsof can't access /dev (or /device) or one of its sub-directories.
@@ -314,6 +444,14 @@
 #define	WARNDEVACCESS	1
 
 
+/*
+ * WARNINGSTATE is defined for those dialects that want to suppress all lsof
+ * warning messages.
+ */
+
+/* #define	WARNINGSTATE	1	warnings are enabled by default */
+
+
 /*
  * WILLDROPGID is defined for those dialects whose lsof executable runs
  * setgid(not_real_GID) and whose setgid power can be relinquished after
@@ -327,4 +465,6 @@
  * zeromem is a macro that uses bzero or memset.
  */
 
-#define	zeromem(a, l)	bzero(a, l)
+#define	zeromem(a, l)	memset(a, 0, l)
+
+#endif	/* !defined(MACHINE_H) */
