@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dstore.c,v 1.7 96/03/24 12:43:29 abe Exp $";
+static char *rcsid = "$Id: dstore.c,v 1.2 98/03/06 08:21:35 abe Exp $";
 #endif
 
 
@@ -54,81 +54,95 @@ struct vfs *AFSVfsp = (struct vfs *)NULL;
 				/* AFS vfs struct kernel address */
 #endif	/* defined(HAS_AFS) */
 
-int Kmem = -1;				/* /dev/kmem file descriptor */
+
+/*
+ * Drive_Nl -- table to drive the building of Nl[] via build_Nl()
+ *             (See lsof.h and misc.c.)
+ */
+
+struct drive_Nl Drive_Nl[] = {
+
+# if	defined(hp9000s300) || defined(__hp9000s300)
+	{ "arFid",	"_afs_rootFid"	},
+	{ "avops",	"_afs_vnodeops"	},
+	{ "avol",	"_afs_volumes"	},
+	{ X_NCACHE,	"_ncache"	},
+	{ X_NCSIZE,	"_ncsize"	},
+	{ "proc",	"_proc"		},
+	{ "nvops",	"_nfs_vnodeops"	},
+	{ "nproc",	"_nproc"	},
+	{ "uvops",	"_ufs_vnodeops"	},
+	{ "vfops",	"_vnodefops"	},
+
+#  if	HPUXV<800
+	{ "upmap",	"_Usrptmap"	},
+	{ "upt",	"_usrpt"	},
+#  endif	/* HPUXV<800 */
+# endif	/* defined(hp9000s300) || defined(__hp9000s300) */
+
+# if	defined(hp9000s800) || defined(__hp9000s800)
+	{ "arFid",	"afs_rootFid"	},
+	{ "avops",	"afs_vnodeops"	},
+	{ "avol",	"afs_volumes"	},
+	{ X_NCACHE,	"ncache"	},
+	{ X_NCSIZE,	"ncsize"	},
+	{ "proc",	"proc"		},
+	{ "nvops",	"nfs_vnodeops"	},
+	{ "nproc",	"nproc"		},
+	{ "uvops",	"ufs_vnodeops"	},
+	{ "vfops",	"vnodefops"	},
+
+#  if	HPUXV<800
+	{ "ubase",	"ubase"		},
+	{ "npids",	"npids"		},
+#  else	/* HPUXV>=800 */
+#   if	HPUXV>=1000
+	{ "cvops",	"cdfs_vnodeops"	},
+	{ "fvops",	"fifo_vnodeops"	},
+	{ "pvops",	"pipe_vnodeops"	},
+	{ "svops",	"spec_vnodeops"	},
+	{ "vvops",	"vx_vnodeops"	},
+#   endif	/* HPUXV>=1000 */
+#  endif	/* HPUXV<800 */
+# endif	/* defined(hp9000s800) || defined(__hp9000s800) */
+
+	{ "",		""		},
+	{ NULL,		NULL		}
+};
+
+
+int Kd = -1;				/* /dev/kmem file descriptor */
+KA_T Kpa;				/* kernel proc structure address */
+
+#if	HPUXV>=1010
+KA_T Ktp;				/* kernel thread pointer from proc
+					 * struct */
+#endif	/* HPUXV>=1010 */
 
 struct l_vfs *Lvfs = NULL;		/* local vfs structure table */
 
-#if	_HPUXV<800
+#if	HPUXV<800
 int Mem = -1;			/* /dev/mem file descriptor */
-#endif	/* _HPUXV<800 */
+#endif	/* HPUXV<800 */
 
-struct nlist Nl[] = {
-
-# if	defined(hp9000s300)
-        { "_afs_rootFID"	},
-        { "_afs_vnodeops"	},
-        { "_afs_volumes"	},
-        { "_ncache"		},
-        { "_ncsize"		},
-        { "_proc"		},
-        { "_nfs_vnodeops"	},
-        { "_nproc"		},
-        { "_ufs_vnodeops"	},
-        { "_vnodefops"		},
-
-#  if	_HPUXV<800
-	{ "_Usrptmap"		},
-	{ "_usrpt"		},
-#  endif	/* _HPUXV<800 */
-# endif	/* defined(hp9000s300) */
-
-# if	defined(hp9000s800)
-        { "afs_rootFid"		},
-        { "afs_vnodeops"	},
-        { "afs_volumes"		},
-        { "ncache"		},
-        { "ncsize"		},
-	{ "proc"		},
-        { "nfs_vnodeops"	},
-	{ "nproc"		},
-        { "ufs_vnodeops"	},
-        { "vnodefops"		},
-
-#  if	_HPUXV<800
-	{ "ubase"		},
-	{ "npids"		},
-#  else	/* _HPUXV>=800 */
-#   if	_HPUXV>=1000
-	{ "cdfs_vnodeops"	},
-	{ "fifo_vnodeops"	},
-	{ "pipe_vnodeops"	},
-	{ "spec_vnodeops"	},
-	{ "vx_vnodeops"		},
-#   endif	/* _HPUXV>=1000 */
-#  endif	/* _HPUXV<800 */
-# endif	/* defined(hp9000s800) */
-
-	{ "" }
-};
-
-#if	_HPUXV<800 && defined(hp9000s800)
+#if	HPUXV<800 && defined(hp9000s800)
 int npids;			/* number of PIDs (for uvadd()) */
 struct proc *proc;		/* process table address (for uvadd()) */
-#endif	/* _HPUXV<800 && defined(hp9000s300) */
+#endif	/* HPUXV<800 && defined(hp9000s300) */
 
-#if	_HPUXV<800
+#if	HPUXV<800
 int Swap = -1;			/* swap device file descriptor */
-#endif	/* _HPUXV<800 */
+#endif	/* HPUXV<800 */
 
-#if	!defined(HPUX7) && defined(hp9000s800)
+#if	HPUXV<800 && defined(hp9000s800)
 struct user *ubase;		/* user area base (for uvadd()) */
-#endif
+#endif	/* HPUXV<800 && defined(hp9000s800) */
 
-#if	!defined(HPUX7) && defined(hp9000s300)
+#if	HPUXV<800 && defined(hp9000s300)
 struct user *ubase;		/* user area base (for uvadd()) */
 struct pte *Usrptmap;		/* user page table map pointer */
 struct pte *usrpt;		/* user page table pointer
 				 * (for bktomx from vmmac.h) */
-#endif
+#endif	/* HPUXV<800 && defined(hp9000s300) */
 
-struct fileops *Vnfops;		/* vnodefops switch address */
+KA_T Vnfops;			/* vnodefops switch address */
