@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.6 96/03/24 12:49:13 abe Exp $
+ * $Id: dlsof.h,v 1.9 98/03/06 08:27:31 abe Exp $
  */
 
 
@@ -39,7 +39,21 @@
 #define	PTX_LSOF_H	1
 
 #include <dirent.h>
+
+# if	PTXV>=420
+#define	_INKERNEL	1
+# endif	/* PTXV>=420 */
+
+# if	PTXV>=430
+#define	_VIEW_OPAQUE_TYPE	1
+# endif	/* PTXV>=430 */
+
 #include <fcntl.h>
+
+# if	PTXV>=420
+#undef	_INKERNEL
+# endif	/* PTXV>=420 */
+
 #include <mntent.h>
 #include <setjmp.h>
 #include <signal.h>
@@ -50,12 +64,12 @@
 #include <sys/time.h>
 #include <sys/vm.h>
 
-# if	_PTXV>=400
+# if	PTXV>=400
 #include <sys/cred.h>
 #include <sys/vm_as.h>
-# else	/* _PTXV<400 */
+# else	/* PTXV<400 */
 #include <sys/swap.h>
-# endif	/* _PTXV>=400 */
+# endif	/* PTXV>=400 */
 
 #include <sys/vnode.h>
 #include <sys/procstats.h>
@@ -63,7 +77,6 @@
 #include <sys/session.h>
 #include <sys/socket.h>
 #undef	AF_OSINET
-#include <sys/socketvar.h>
 #include <sys/snode.h>
 #include <sys/sysmacros.h>
 #include <sys/swap.h>
@@ -73,44 +86,94 @@
 #include <sys/ufsmount.h>
 #include <netinet/in.h>
 
+# if	PTXV<400
+#define	u_char	RPC_u_char
+#define	u_short	RPC_u_short
+#define	u_long	RPC_u_long
+# endif	/* PTXV<400 */
+
+#include <rpc/rpc.h>
+#include <rpc/pmap_prot.h>
+
+# if	PTXV>=400
+#include <rpc/rpc_soc.h>
+# endif	/* PXV>=400 */
+
+# if	PTXV<400
+#undef	RPC_u_char
+#undef	RPC_u_short
+#undef	RPC_u_long
+# endif	/* PTXV<400 */
+
 # if	defined(HAS_NFS)
 #include <nfs/nfs.h>
 #include <nfs/nfs_clnt.h>
 
-#  if	_PTXV<400
+#  if	PTXV<400
 #include <nfs/rnode.h>
-#  else	/* _PTXV>=400 */
+#  else	/* PTXV>=400 */
 #include "/usr/conf/uts/nfs/rnode.h"
-#  endif	/* _PTXV<400 */
+#  endif	/* PTXV<400 */
 # endif	/* defined(HAS_NFS) */
 
-# if	_PTXV<400
+# if	PTXV<400
 #define _INKERNEL
-# endif	/* _PTXV<400 */
+# endif	/* PTXV<400 */
 
 #include <sys/fifonode.h>
 #include <sys/file.h>
 
-# if	_PTXV>=400
+# if	PTXV>=400
 #define	_INKERNEL	1
+#define	INKERNEL	1
 #include <sys/namenode.h>
 #undef	_INKERNEL
-# endif	/* _PTXV>=400 */
+#undef	INKERNEL
+# endif	/* PTXV>=400 */
 
 #include <sys/stream.h>
+#include <sys/tihdr.h>
 #include <sys/tiuser.h>
+
+# if	PTXV>=421
+#include <sys/unpcb.h>
+# endif	/* PTXV>=421 */
+
+# if	PTXV>=413
+#include <sys/domain.h>
+#include <sys/protosw.h>
+#  if	PTXV>=430
+#define	_INKERNEL	1
+#  else	/* PTXV<430 */
+#define	INKERNEL	1
+#  endif	/* PTXV>=430 */
 #include <sys/sockmod.h>
+#  if	PTXV>=430
+#undef	_INKERNEL
+#  else	/* PTXV<430 */
+#undef	INKERNEL
+#  endif	/* PTXV>=430 */
+# else	/* PTXV<413 */
+#include <sys/sockmod.h>
+# endif	/* PTXV>=413 */
+
+#include <sys/socketvar.h>
 #include <sys/user.h>
 
-# if	_PTXV<400
+# if	PTXV<400
 #undef _INKERNEL
-# endif	/* _PTXV<400 */
+# endif	/* PTXV<400 */
+
+# if	PTXV>=413
+#include <netinet/ip.h>
+# endif	/* PTXV>=413 */
 
 #include <netinet/in_pcb.h>
 #include <netinet/ip_var.h>
 #include <netinet/tcp.h>
-#include <netinet/tcp_timer.h>
 #include <netinet/tcpip.h>
+#include <netinet/tcp_fsm.h>
+#include <netinet/tcp_timer.h>
 #include <netinet/tcp_var.h>
 
 
@@ -133,6 +196,13 @@
 #define	READLEN_T	size_t
 #define STRNCPY_L	size_t
 #define SWAP		"/dev/swap"
+
+# if	PTXV>=400
+#define	SZOFFTYPE	unsigned long long
+				/* type for size and offset */
+#define	SZOFFPSPEC	"ll"	/* SZOFFTYPE printf specification modifier */
+# endif	/* PTXV>=400 */
+
 #define	U_SIZE		sizeof(struct user)
 
 
@@ -148,10 +218,10 @@ extern struct clone *Clone;
 
 extern int CloneMajor;			/* clone major device number */
 extern int HaveCloneMajor;		/* CloneMajor status */
-extern int Kmem;
+extern int Kd;
 
 struct l_vfs {
-	struct vfs *addr;		/* kernel address */
+	KA_T addr;			/* kernel address */
 	dev_t dev;			/* device */
 	char *dir;			/* mounted directory */
 	char *fsname;			/* file system name */
@@ -165,35 +235,22 @@ struct l_vfs {
 extern struct l_vfs *Lvfs;
 
 struct mounts {
-        dev_t dev;              	/* st_dev */
-        char *dir;              	/* directory */
-        char *fsname;           	/* file system */
-	ino_t inode;			/* st_ino */
-	mode_t mode;			/* st_mode */
+        char *dir;              	/* directory (mounted on) */
+	char *fsname;           	/* file system
+					 * (symbolic links unresolved) */
+	char *fsnmres;           	/* file system
+					 * (symbolic links resolved) */
+        dev_t dev;              	/* directory st_dev */
+	dev_t rdev;			/* directory st_rdev */
+	ino_t inode;			/* directory st_ino */
+	mode_t mode;			/* directory st_mode */
+	mode_t fs_mode;			/* file system st_mode */
         struct mounts *next;    	/* forward link */
-	dev_t rdev;			/* st_rdev */
 };
 
-
-/*
- * Name list (Nl[]) indexes
- */
-
-#define X_ASOPSLARGE	0
-#define X_ASOPSSMALL	1
-#define	X_CDFSOPS	2
-#define	X_CLONEMAJ	3
-#define	X_FIFOOPS	4
-#define	X_NCACHE	5
-#define	X_NCSIZE	6
-#define X_NFSOPS	7
-#define	X_NMOPS		8
-#define	X_NOFILE	9
-#define X_PROC          10
-#define	X_SPECOPS	11
-#define	X_UFSOPS	12
-#define	X_VAR		13
-#define	X_VXFSOPS	14
+#define	X_NCACHE	"ncache"
+#define	X_NCSIZE	"ncsize"
+#define	NL_NAME		n_name
 
 extern int Notkmem;
 
@@ -210,6 +267,38 @@ struct sfile {
 	struct sfile *next;		/* forward link */
 };
 
+# if	PTXV<400
 extern int Swap;
+# endif	/* PTXV<400 */
+
+
+/*
+ * Definition for rdev.c
+ */
+
+#define	DIRTYPE	dirent
+
+
+/*
+ * Definition for cvfs.c
+ */
+
+#define	CVFS_DEVSAVE 	1
+
+
+/*
+ * Definitions for rnch.c
+ */
+
+# if     defined(HASNCACHE) && !defined(HASVXFSDNLC)
+#include <sys/dnlc.h>
+# endif  /* defined(HASNCACHE) && !defined(HASVXFSDNLC) */
+
+# if	PTXV>=442
+#define	NCACHE_DP	nc_dp
+#define	NCACHE_NAME	nc_name
+#define	NCACHE_NAMLEN	nc_namelen
+#define	NCACHE_VP	nc_vp
+# endif	/* PTXV>=442 */
 
 #endif	/* PTX_LSOF_H */
