@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1995 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dmnt.c,v 1.5 96/04/05 09:51:51 abe Exp $";
+static char *rcsid = "$Id: dmnt.c,v 1.2 98/03/06 08:27:32 abe Exp $";
 #endif
 
 
@@ -49,6 +49,7 @@ readvfs(va)
 {
 	dev_t d;
 	int ds = 0;
+	KA_T ka;
 	struct vfs tv;
 	struct vnode v;
 	struct l_vfs *vp;
@@ -57,19 +58,19 @@ readvfs(va)
 	struct mntinfo mi;
 #endif	/* defined(HAS_NFS) */
 
-	if (!va->v_vfsp)
-		return(NULL);
+	if (!(ka = (KA_T)va->v_vfsp))
+	    return((struct l_vfs *)NULL);
 	for (vp = Lvfs; vp; vp = vp->next) {
-		if (va->v_vfsp == vp->addr)
-			return(vp);
+	    if (ka == vp->addr)
+		return(vp);
 	}
-	if ((vp = (struct l_vfs *)malloc(sizeof(struct l_vfs))) == NULL) {
-		(void) fprintf(stderr, "%s: PID %d, no space for vfs\n",
-			Pn, Lp->pid);
-		Exit(1);
+	if (!(vp = (struct l_vfs *)malloc(sizeof(struct l_vfs)))) {
+	    (void) fprintf(stderr, "%s: PID %d, no space for vfs\n",
+		Pn, Lp->pid);
+	    Exit(1);
 	}
-	vp->dir = NULL;
-	vp->fsname = NULL;
+	vp->dir = (char *)NULL;
+	vp->fsname = (char *)NULL;
 
 #if	defined(HASFSINO)
 	vp->fs_ino = 0;
@@ -87,11 +88,11 @@ readvfs(va)
 	 * device number is a serial found in the mntinfo structure
 	 * addressed by the virtual file system's vfs_data pointer.
 	 */
-	    if (kread((KA_T)va->v_vfsp, (char *)&tv, sizeof(tv))) {
+	    if (kread(ka, (char *)&tv, sizeof(tv))) {
 		(void) free((FREE_P *)vp);
-		return(NULL);
+		return((struct l_vfs *)NULL);
 	    }
-	    if (kread((KA_T)tv.vfs_data, (char *)&mi, sizeof(mi)) == 0) {
+	    if (!kread((KA_T)tv.vfs_data, (char *)&mi, sizeof(mi))) {
 		d = (dev_t)makedev(255, (int)mi.mi_mntno);
 		ds = 1;
 	    }
@@ -105,43 +106,32 @@ readvfs(va)
 	 * of the block device on which the file system is mounted.
 	 */
 	    if (va->v_devvp
-	    &&  kread((KA_T)va->v_devvp, (char *)&v, sizeof(v)) == 0) {
+	    &&  !kread((KA_T)va->v_devvp, (char *)&v, sizeof(v))) {
 		d = v.v_rdev;
 		ds = 1;
 	    } else {
 		if (kread((KA_T)va->v_vfsp, (char *)&tv, sizeof(tv))) {
 		    (void) free((FREE_P *)vp);
-		    return(NULL);
+		    return((struct l_vfs *)NULL);
 	        }
 
-#if	_PTXV<400
+#if	PTXV<400
 		if (tv.vfs_devvp
-		&&  kread((KA_T)tv.vfs_devvp, (char *)&v, sizeof(v)) == 0) {
+		&&  !kread((KA_T)tv.vfs_devvp, (char *)&v, sizeof(v))) {
 		    d = v.v_rdev;
 		    ds = 1;
 		}
-#else	/* _PTXV>=400 */
+#else	/* PTXV>=400 */
 		if ((d = tv.vfs_dev) != 0)
 		    ds = 1;
-#endif	/* _PTXV<400 */
+#endif	/* PTXV<400 */
 
 	    }
 	}
 	if (ds)
 	    (void) completevfs(vp, &d);
 	vp->next = Lvfs;
-	vp->addr = va->v_vfsp;
+	vp->addr = ka;
 	Lvfs = vp;
 	return(vp);
 }
-
-
-/*
- * The readmnt() function is obtained from ../common/rmnt.frag.
- * The completevfs() function is obtained from ../common/cvfs.frag.
- */
-
-#define	CVFS_DEVSAVE 	1
-#define	EXPDEV(n)	n
-/* MNTSKIP is not defined. */
-#define	USECVFS		1
