@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1995 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dstore.c,v 1.2 96/03/24 12:49:33 abe Exp $";
+static char *rcsid = "$Id: dstore.c,v 1.2 97/04/07 09:28:00 abe Exp $";
 #endif
 
 
@@ -45,28 +45,41 @@ static char *rcsid = "$Id: dstore.c,v 1.2 96/03/24 12:49:33 abe Exp $";
 
 struct clone *Clone = NULL;		/* clone devices */
 int CloneMajor;				/* clone major device number */
-int HaveCloneMajor = 0;			/* CloneMajor status */
-int Kmem = -1;				/* /dev/kmem file descriptor */
-struct l_vfs *Lvfs = NULL;		/* local vfs structure table */
 
-struct nlist Nl[] = {
-	{ "asops_large"		},
-	{ "asops_small"		},
-	{ "cdfs_vnodeops"	},
-	{ "clone_c_major"	},
-	{ "fifo_vnodeops"	},
-        { "ncache"		},
-        { "ncsize"		},
-        { "nfs_vnodeops"	},
-        { "nm_vnodeops"		},
-        { "Nofile"		},
-        { "proc"		},
-	{ "spec_vnodeops"	},
-	{ "ufs_vnodeops"	},
-	{ "v"			},
-	{ "vx_vnodeops"		},
-	{ "" },
+
+/*
+ * Drive_Nl -- table to drive the building of Nl[] via build_Nl()
+ *             (See lsof.h and misc.c.)
+ */
+
+struct drive_Nl Drive_Nl[] = {
+	{ "asoplg",	"asops_large"	},
+	{ "asopsm",	"asops_small"	},
+	{ "cvops",	"cdfs_vnodeops"	},
+	{ "clmaj",	"clone_c_major"	},
+	{ "fvops",	"fifo_vnodeops"	},
+        { X_NCACHE,	"ncache"	},
+        { X_NCSIZE,	"ncsize"	},
+        { "nfsvops",	"nfs_vnodeops"	},
+        { "nmvops",	"nm_vnodeops"	},
+        { "nofile",	"Nofile"	},
+        { "proc",	"proc"		},
+	{ "sckvops",	"sock_vnodeops"	},
+	{ "spvops",	"spec_vnodeops"	},
+	{ "uvops",	"ufs_vnodeops"	},
+	{ "var",	"v"		},
+	{ "vvops",	"vx_vnodeops"	},
+	{ "vxdnlc",	"vx_dnlc_hash"	},
+	{ "vxndnlc",	"vx_dnlc_nhash"	},
+	{ "",		""		},
+	{ NULL,		NULL,		}
 };
 
+int HaveCloneMajor = 0;			/* CloneMajor status */
+int Kd = -1;				/* /dev/kmem file descriptor */
+struct l_vfs *Lvfs = NULL;		/* local vfs structure table */
 int Notkmem = 0;			/* core file is not /dev/kmem */
+
+# if	PTXV<400
 int Swap = -1;				/* swap device file descriptor */
+# endif	/* PTXV<400 */
