@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.30 96/04/01 16:36:42 abe Exp $
+ * $Id: dlsof.h,v 1.11 98/03/06 08:38:22 abe Exp $
  */
 
 
@@ -42,7 +42,13 @@
 #include <fcntl.h>
 #include <sys/mntent.h>
 #include <sys/mnttab.h>
+
+#  if	solaris<20600
 #define	_KMEMUSER	1
+#  else	/* solaris>=20600 */
+#include <stddef.h>
+#  endif	/* solaris<20600 */
+
 # else		/* not solaris */
 #include <mntent.h>
 #include <sys/domain.h>
@@ -59,37 +65,56 @@
 #include <rpc/types.h>
 #include <sys/protosw.h>
 #include <sys/socket.h>
+
+# if	!defined(solaris)
 #include <sys/socketvar.h>
+# endif	/* !defined(solaris) */
+
 #include <sys/un.h>
+#include <sys/wait.h>
 #include <netinet/in.h>
 
 # if	defined(solaris)
 #define	_KERNEL
 #define	MI_HRTIMING
-#define	pfi_t	int
-#define	pfv_t	int
 #include <inet/led.h>
+
+#  if	solaris<20600
+#undef	staticf
+#  endif	/* solaris<20600 */
+
+#include <inet/common.h>
 #include <inet/mi.h>
+
 #include <inet/ip.h>
 #undef	_KERNEL
 #undef	MI_HRTIMING
-#undef	pfi_t
-#undef	pfv_t
 #define	exit		kernel_exit
 #define	rval_t		char
 #define	strsignal	kernel_strsignal
 #include <sys/strsubr.h>
+#include <sys/socketvar.h>
 #undef	exit
 #undef	rval_t
 #undef	strsignal
 #include <inet/tcp.h>
 # else	/* !solaris */
+#include <netinet/tcp.h>
+#include <netinet/tcp_fsm.h>
+#include <netinet/tcp_timer.h>
+#include <netinet/tcp_var.h>
 #include <sys/unpcb.h>
 # endif	/*  solaris */
 
 #include <net/route.h>
 #include <netinet/in_pcb.h>
 #include <sys/stream.h>
+
+# if	defined(solaris) && solaris<20600
+#undef	MAX
+#undef	MIN
+# endif	/* defined(solaris) && solaris<20600 */
+
 #include <sys/sysmacros.h>
 #include <sys/vfs.h>
 #include <sys/vnode.h>
@@ -98,14 +123,40 @@
 #include <sys/fs/hsfs_spec.h>
 #include <sys/fs/hsfs_node.h>
 #include <sys/fs/lofs_node.h>
+
+#  if	solaris>=20600
+#define	_KERNEL
+#  endif	solaris>=20600
+
 #include <sys/fs/namenode.h>
 
+#  if	solaris>=20600
+#undef	_KERNEL
+#  endif	solaris>=20600
+
+#include <sys/tihdr.h>
+
 #  if	solaris>=20500
+#include <sys/tiuser.h>
+#include <rpc/auth.h>
+#include <rpc/clnt.h>
+#include <rpc/clnt_soc.h>
+#include <rpc/pmap_prot.h>
 #define	_KERNEL
+#include <sys/fs/autofs.h>
 #include <sys/door.h>
 #undef	_KERNEL
+#  else	/* solaris<20500 */
+#include <rpc/rpc.h>
+#include <rpc/clnt_soc.h>
+#include <rpc/pmap_prot.h>
 #  endif	/* solaris>=20500 */
+#  if	!defined(_NETDB_H_)
+#include <rpc/rpcent.h>
+#  endif	/* !defined(_NETDB_H_) */
 # else	/* !solaris */
+#include <rpc/rpc.h>
+#include <rpc/pmap_prot.h>
 
 /*
  * Dummy hsnode structure for SunOS 4.1.3 and below.  This should come from
@@ -126,22 +177,39 @@ struct  hsnode {
 #include <sys/t_lock.h>
 #include <sys/flock.h>
 
-# if	solaris>=20300
-#  if	solaris<20400
+#  if	solaris>=20300
+#   if	solaris<20400
 /*
  * The lock_descriptor structure definition is missing from Solaris 2.3.
  */
 
 struct lock_descriptor {
-	u_long d1[5];
+	struct lock_descriptor *prev;
+	struct lock_descriptor *next;
+	struct vnode *vnode;
+	struct owner {
+		pid_t pid;
+		long sysid;
+	} owner;
 	int flags;
 	short type;
+	off_t start;
+	off_t end;
+	struct lock_info {
+		struct active_lock_info {
+			struct lock_descriptor *ali_stack;
+		} li_active;
+		struct sleep_lock_info {
+			struct flock sli_flock;
+			/* Ignore the rest. */
+		} li_sleep;
+	} info;
 };
 #define	ACTIVE_LOCK	0x008		/* lock is active */
-#  else	/* solaris>=20400 */
+#   else	/* solaris>=20400 */
 #include <sys/flock_impl.h>
-#  endif	/* solaris<20400 */
-# endif	/* solaris>=20300 */
+#   endif	/* solaris<20400 */
+#  endif	/* solaris>=20300 */
 
 #include <sys/fstyp.h>
 #include <sys/dditypes.h>
@@ -154,9 +222,13 @@ struct lock_descriptor {
 #include <sys/fs/pc_dir.h>
 #include <sys/fs/pc_label.h>
 #include <sys/fs/pc_node.h>
+
+#  if	solaris>=20600
+#undef	SLOCKED
+#  endif	/* solaris>=20600 */
+
 #include <sys/fs/snode.h>
 #include <sys/fs/tmpnode.h>
-#include <sys/fs/ufs_inode.h>
 # else	/* !solaris */
 #include <net/raw_cb.h>
 #include <ufs/lockf.h>
@@ -175,7 +247,7 @@ struct lock_descriptor {
 
 # if	defined(HASPROCFS)
 #include <sys/proc/prdata.h>
-# endif
+# endif	/* defined(HASPROCFS) */
 
 
 # if	!defined(solaris)
@@ -233,7 +305,7 @@ extern char *sys_errlist[];
 
 #define	CWDLEN		(MAXPATHLEN+1)
 #define DEVINCR		1024	/* device table malloc() increment */
-#define	KA_T		off_t
+#define	KA_T		unsigned long
 #define	KMEM		"/dev/kmem"
 #define MALLOC_P	char
 #define FREE_P		MALLOC_P
@@ -252,6 +324,7 @@ extern char *sys_errlist[];
 
 # else	/* !defined(solaris) */
 #define CLONEMAJ	37	/* major device number for clone device */
+#define	MEMMOVE		memcpy	/* for fill_portmap() in print.c */
 #define N_UNIX		"/vmunix"
 #define	PROCMIN		3	/* processes that make a "good" scan */
 # endif	/* defined(solaris) */
@@ -263,7 +336,13 @@ extern char *sys_errlist[];
 #define	READLEN_T	int
 #define STRNCPY_L	int
 #define	STRNML		32	/* stream name length (maximum) */
-#define	UIDCACHEL	8192
+
+# if	defined(solaris) && solaris>=20600
+#define	SZOFFTYPE	unsigned long long
+				/* size and offset internal storage type */
+#define	SZOFFPSPEC	"ll"	/* SZOFFTYPE print specification modifier */
+# endif	/* defined(solaris) && solaris>=20600 */
+
 #define U_SIZE		sizeof(struct user)
 
 
@@ -281,33 +360,31 @@ extern char *AFSApath;		/* alternate AFS name list path (from -a) */
 extern int AFSfstype;		/* AFS file system type index */
 #  endif	/* defined(solaris) */
 
-extern struct vfs *AFSVfsp;	/* AFS struct vfs kernel pointer */
+KA_T AFSVfsp;			/* AFS struct vfs kernel pointer */
 # endif	/* defined(HAS_AFS) */
 
 struct clone {
-	char *nm;		/* path name */
-	dev_t rdev;		/* device number */
+	struct l_dev cd;	/* device, inode, name, and verify */
 	int n;			/* network flag */
 	struct clone *next;	/* forward link */
 };
 extern struct clone *Clone;
 
-extern int CloneMaj;
-
-# if	!defined(solaris)
-extern char *Cwd;
-# endif
-
 # if	defined(solaris)
+extern	major_t	CloneMaj;
 extern char **Fsinfo;
 extern int Fsinfomax;
-# endif
+# else	/* !defined(solaris) */
+extern char *Cwd;
+extern struct file *Fileptr;
+#define	FILEPTR	Fileptr			/* for process_file() in dfile.c */
+# endif	/* defined(solaris) */
 
 extern int HaveCloneMaj;
 extern kvm_t *Kd;
 
 struct l_vfs {
-	struct vfs *addr;		/* kernel address */
+	KA_T addr;			/* kernel address */
 	char *dir;			/* mounted directory */
 	char *fsname;			/* file system name */
 	dev_t dev;			/* device */
@@ -321,87 +398,35 @@ struct l_vfs {
 extern struct l_vfs *Lvfs;
 
 struct mounts {
-        dev_t dev;              	/* st_dev */
-        char *dir;              	/* directory */
-        char *fsname;           	/* file system */
-	ino_t inode;			/* st_ino */
-	mode_t mode;			/* st_mode */
+        char *dir;              	/* directory (mounted on) */
+        char *fsname;           	/* file system
+					 * (symbolic links unresolved) */
+	char *fsnmres;			/* file system
+					 * (symbolic links resolved) */
+        dev_t dev;              	/* directory st_dev */
+	dev_t rdev;			/* directory st_rdev */
+	ino_t inode;			/* directory st_ino */
+	mode_t mode;			/* directory st_mode */
+	mode_t fs_mode;			/* file system st_mode */
         struct mounts *next;    	/* forward link */
 
 # if	defined(HASFSTYPE)
 	char *fstype;			/* file system type */
 # endif
 
-	dev_t rdev;			/* st_rdev */
 };
 
-
-/*
- * Name list (Nl[]) indexes
- */
-
-# if	defined(solaris)
-#define	X_AFS_FID	0
-#define	X_AFS_OPS	1
-#define	X_AFS_VOL	2
-#define X_CACHE_OPS	3
-#define	X_CLONEMAJ	4
-#define X_FIFO_OPS	5
-#define X_HSFS_OPS	6
-#define	X_LOFS_OPS	7
-#define	X_MVFS_OPS	8
-#define	X_NCACHE	9
-#define	X_NCSIZE	10
-#define X_NFS_OPS	11
-#define X_NFS3_OPS	12
-#define X_NM_OPS	13
-#define	X_NPROC		14
-#define	X_PC_DOPS	15
-#define	X_PC_FOPS	16
-#define X_PROC_OPS	17
-#define X_SEGVN		18
-#define	X_SPEC_OPS	19
-#define X_TMP_OPS	20
-#define X_UFS_OPS	21
-# if	solaris<20500
-#define	X_LAST		22
-# else	/* solaris>=20500 */
-#define X_DOOR_OPS	22
-#define	X_KERNELBASE	23
-#define X_LAST		24
-# endif	/* solaris<20500 */
-# else		/* !solaris */
-#define	X_AFS_FID	0
-#define	X_AFS_OPS	1
-#define	X_AFS_VOL	2
-#define X_FIFO_OPS	3
-#define X_HSFS_OPS	4
-#define	X_NCACHE	5
-#define	X_NCSIZE	6
-#define X_NFS_OPS	7
-#define X_NFS3_OPS	8
-#define	X_NPROC		9
-#define	X_PC_DOPS	10
-#define	X_PC_FOPS	11
-#define X_SEGVN		12
-#define	X_SPEC_OPS	13
-#define X_TMP_OPS	14
-#define X_UFS_OPS	15
-#define	X_LAST		16
-# endif	/* solaris */
-
 # if	defined(solaris)
 struct pseudo {
-	char *nm;			/* path name */
-	dev_t rdev;			/* device number */
+	struct l_dev pd;		/* device, inode, path, verify */
 	struct pseudo *next;		/* forward link */
 };
 extern struct pseudo *Pseudo;
 # endif	/* solaris */
 
-#if	!defined(solaris)
+# if	!defined(solaris)
 extern char *Rtd;
-#endif
+# endif	/* !defined(solaris) */
 
 struct sfile {
 	char *aname;			/* file name argument */
@@ -416,4 +441,50 @@ struct sfile {
 	struct sfile *next;		/* forward link */
 };
 
+
+/*
+ * Kernel name list definitions
+ */
+
+#define	NL_NAME		n_name
+#define	X_NCACHE	"ncache"
+#define	X_NCSIZE	"ncsize"
+
+
+/*
+ * Definitions for dvch.c
+ */
+
+# if	defined(HASDCACHE)
+#define	DCACHE_CLONE	rw_clone_sect	/* clone function for read_dcache */
+#define	DCACHE_CLR	clr_sect	/* function to clear clone and
+					 * pseudo caches when reading the
+					 * device cache file fails */
+#  if	defined(solaris)
+#define	DCACHE_PSEUDO	rw_pseudo_sect	/* pseudo function for read_dcache */
+#  endif	/* defined_solaris */
+# endif	/* defined(HASDCACHE) */
+
+# if	defined(solaris)
+#define	DVCH_DEVPATH	"/devices"
+# else	/* !defined(solaris) */
+#define	DVCH_DEVPATH	"/dev"
+# endif	/* defined(solaris) */
+
+
+/*
+ * Definition for cvfs.c
+ */
+
+#define	CVFS_DEVSAVE 	1
+
+
+/*
+ * Definitions for rnch.c
+ */
+
+# if	defined(HASNCACHE)
+#include <sys/dnlc.h>
+# endif	/* defined(HASNCACHE) */
+
 #endif	/* SUN_LSOF_H */
