@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dmnt.c,v 1.16 96/04/05 09:49:32 abe Exp $";
+static char *rcsid = "$Id: dmnt.c,v 1.3 98/03/06 08:38:24 abe Exp $";
 #endif
 
 
@@ -57,14 +57,14 @@ getmntdev(o, l, s, f)
 	char *opte;
 
 	memset((char *)s, 0, sizeof(struct stat));
-	if ((opte = x2dev(o + l + 1, &s->st_dev)) == NULL)
-		return(NULL);
+	if (!(opte = x2dev(o + l + 1, &s->st_dev)))
+	    return((char *)NULL);
 	s->st_mode = S_IFDIR | 0777;
 
 #if	defined(HASFSTYPE)
 	if (f) {
-		(void) strncpy(s->st_fstype, f, sizeof(s->st_fstype));
-		s->st_fstype[sizeof(s->st_fstype) - 1] = '\0';
+	    (void) strncpy(s->st_fstype, f, sizeof(s->st_fstype));
+	    s->st_fstype[sizeof(s->st_fstype) - 1] = '\0';
 	}
 #endif	/* defined(HASFSTYPE) */
 
@@ -80,7 +80,7 @@ int
 readmnt()
 {
 	int devl, ignore;
-	char *dn = NULL;
+	char *dn = (char *)NULL;
 	int err = 0;
 	char *ln;
 	FILE *mfp;
@@ -91,31 +91,31 @@ readmnt()
 #if	defined(solaris)
 	struct mnttab me;
 	struct mnttab *mp;
-#else
+#else	/* !defined(solaris) */
 	struct mntent *mp;
-#endif
+#endif	/* defined(solaris) */
 
 #if	defined(HASPROCFS)
 	int procfs = 0;
-#endif
+#endif	/* defined(HASPROCFS) */
 
 /*
  * Open access to the mount table and read mount table entries.
  */
 
 #if	defined(solaris)
-	if ((mfp = fopen(MNTTAB, "r")) == NULL) {
-                (void) fprintf(stderr, "%s: can't access %s\n", Pn, MNTTAB);
-                return(0);
+	if (!(mfp = fopen(MNTTAB, "r"))) {
+            (void) fprintf(stderr, "%s: can't access %s\n", Pn, MNTTAB);
+            return(0);
         }
 	for (mp = &me; getmntent(mfp, mp) == 0;)
-#else
-        if ((mfp = setmntent(MOUNTED, "r")) == NULL) {
-                (void) fprintf(stderr, "%s: can't access %s\n", Pn, MOUNTED);
-                return(0);
+#else	/* !defined(solaris) */
+        if (!(mfp = setmntent(MOUNTED, "r"))) {
+            (void) fprintf(stderr, "%s: can't access %s\n", Pn, MOUNTED);
+            return(0);
         }
-        while ((mp = getmntent(mfp)) != NULL)
-#endif	/* solaris */
+        while ((mp = getmntent(mfp)))
+#endif	/* defined(solaris) */
 
 	{
 
@@ -126,64 +126,53 @@ readmnt()
 	 */
 
 #if	defined(solaris)
-		if (strcmp(mp->mnt_fstype, MNTTYPE_LO) == 0)
+	    if (strcmp(mp->mnt_fstype, MNTTYPE_LO) == 0)
 #else	/* !defined(solaris) */
-		if (strcmp(mp->mnt_type, MNTTYPE_LO) == 0)
+	    if (strcmp(mp->mnt_type, MNTTYPE_LO) == 0)
 #endif	/* defined(solaris) */
 
-			continue;
+		continue;
 /*
  * Check for a "ignore" type (SunOS) or "ignore" option (Solaris).
  */
 
 #if	defined(solaris)
-		if (hasmntopt(mp, MNTOPT_IGNORE))
+	    if (hasmntopt(mp, MNTOPT_IGNORE))
 #else	/* !defined(solaris) */
-		if (strcmp(mp->mnt_type, MNTTYPE_IGNORE) == 0)
+	    if (strcmp(mp->mnt_type, MNTTYPE_IGNORE) == 0)
 #endif	/* defined(solaris) */
 
-			ignore = 1;
-		else
-			ignore = 0;
-
+		ignore = 1;
+	    else
+		ignore = 0;
 	/*
-	 * Interpolate a possible symbolic directory link, unless this
-	 * is an "ignore" entry.
+	 * Interpolate a possible symbolic directory link.
 	 */
-		if (dn)
-			(void) free((FREE_P *)dn);
+	    if (dn)
+		(void) free((FREE_P *)dn);
 
 #if	defined(solaris)
-		if ((dn=(char *)malloc((MALLOC_S)(strlen(mp->mnt_mountp) + 1)))
-#else
-		if ((dn = (char *)malloc((MALLOC_S)(strlen(mp->mnt_dir) + 1)))
-#endif
-		== NULL) {
-			err = 1;
-			break;
-		}
+	    if (!(dn = mkstrcpy(mp->mnt_mountp, (MALLOC_S *)NULL)))
+#else	/* !defined(solaris) */
+	    if (!(dn = mkstrcpy(mp->mnt_dir, (MALLOC_S *)NULL)))
+#endif	/* defined(solaris) */
 
-#if	defined(solaris)
-		(void) strcpy(dn, mp->mnt_mountp);
-#else
-		(void) strcpy(dn, mp->mnt_dir);
-#endif
-
-		if (!ignore) {
-		    if ((ln = Readlink(dn)) == NULL) {
-			if (!Fwarn) {
-			    (void) fprintf(stderr,
-			      "      Output information may be incomplete.\n");
-			}
-			err = 2;
-			continue;
-		    }
-		} else
-		    ln = dn;
-		if (ln != dn) {
-			(void) free((FREE_P *)dn);
-			dn = ln;
+	    {
+		err = 1;
+		break;
+	    }
+	    if (!(ln = Readlink(dn))) {
+		if (!Fwarn) {
+		    (void) fprintf(stderr,
+			"      Output information may be incomplete.\n");
 		}
+		err = 2;
+		continue;
+	    }
+	    if (ln != dn) {
+		(void) free((FREE_P *)dn);
+		dn = ln;
+	    }
 	/*
 	 * Stat() the directory.
 	 *
@@ -193,166 +182,182 @@ readmnt()
 	 */
 
 #if	defined(solaris)
-		opt = hasmntopt(mp, MNTOPT_DEV);
-		devl = strlen(MNTOPT_DEV);
+	    opt = hasmntopt(mp, MNTOPT_DEV);
+	    devl = strlen(MNTOPT_DEV);
 #else	/* !defined(solaris) */
-		opt = hasmntopt(mp, MNTINFO_DEV);
-		devl = strlen(MNTINFO_DEV);
+	    opt = hasmntopt(mp, MNTINFO_DEV);
+	    devl = strlen(MNTINFO_DEV);
 #endif	/* defined(solaris) */
 
-		if (ignore) {
-		    if (opt == NULL
-		    ||  (opte = getmntdev(opt, devl, &sb,
+	    if (ignore) {
+		if (!opt
+		||  !(opte = getmntdev(opt, devl, &sb,
 
 #if	defined(HASFSTYPE)
 # if	defined(solaris)
-					  mp->mnt_fstype
+			     mp->mnt_fstype
 # else	/* !defined(solaris) */
-					  NULL
+			     (char *)NULL
 # endif	/* defined(solaris) */
 #else	/* !defined(HASFSTYPE) */
-					  NULL
-#endif	/* defined(hasfstype) */
+			     (char *)NULL
+#endif	/* defined(HASFSTYPE) */
 
 		    ))
-		    == NULL)
-			continue;
-		} else if (statsafely(dn, &sb)) {
-		    if (!Fwarn) {
+		)
+		    continue;
+	    } else if (statsafely(dn, &sb)) {
+		if (!Fwarn) {
 			(void) fprintf(stderr,
-			    "%s: WARNING: can't stat() %s file system %s\n",
+			    "%s: WARNING: can't stat() ", Pn);
 
 #if	defined(solaris)
-			    Pn, mp->mnt_fstype, mp->mnt_mountp);
+			safestrprt(mp->mnt_fstype, stderr, 0);
+			(void) fprintf(stderr, " file system ");
+			safestrprt(mp->mnt_mountp, stderr, 1);
 #else	/* !defined(solaris) */
-			    Pn, mp->mnt_type, mp->mnt_dir);
+			safestrprt(mp->mnt_type, stderr, 0);
+			(void) fprintf(stderr, " file system ");
+			safestrprt(mp->mnt_dir, stderr, 1);
 #endif	/* defined(solaris) */
 
 			(void) fprintf(stderr,
 			    "      Output information may be incomplete.\n");
-		    }
-		    err = 2;
-		    if (opt != NULL) {
-			if ((opte = getmntdev(opt, devl, &sb,
+		}
+		err = 2;
+		if (opt) {
+		    if (!(opte = getmntdev(opt, devl, &sb,
 
 #if	defined(HASFSTYPE)
 # if	defined(solaris)
-					      mp->mnt_fstype
+					   mp->mnt_fstype
 # else	/* !defined(solaris) */
-					      NULL
+					   (char *)NULL
 # endif	/* defined(solaris) */
 #else	/* !defined(HASFSTYPE) */
-					      NULL
-#endif	/* defined(hasfstype) */
+					   (char *)NULL
+#endif	/* defined(HASFSTYPE) */
 
 			))
-			!= NULL) {
-			    if (!Fwarn)
-				(void) fprintf(stderr,
-				    "      assuming \"%.*s\" from %s\n",
-				    (opte - opt), opt,
+		    ) {
+			if (!Fwarn) {
+			    (void) fprintf(stderr,
+				"      assuming \"%.*s\" from %s\n",
+				(opte - opt), opt,
 
 #if	defined(solaris)
-				    MNTTAB
+				MNTTAB
 #else	/* !defined(solaris) */
-				    MOUNTED
+				MOUNTED
 #endif	/* defined(solaris) */
 
-				);
-			} else
-			    opt = NULL;
-		    }
-		    if (opt == NULL)
-			continue;
+			    );
+			}
+		    } else
+			opt = (char *)NULL;
 		}
+		if (!opt)
+		    continue;
+	    }
 	/*
 	 * Allocate and fill a local mount structure.
 	 */
-		if ((mtp = (struct mounts *)malloc(sizeof(struct mounts)))
-		== NULL) {
-			err = 1;
-			break;
-		}
-		if ((mtp->fsname =
-
-#if	defined(solaris)
-			(char *)malloc((MALLOC_S)(strlen(mp->mnt_special)+1)))
-#else
-			(char *)malloc((MALLOC_S)(strlen(mp->mnt_fsname)+1)))
-#endif
-
-		== NULL) {
-			err = 1;
-			break;
-		}
-
-#if	defined(solaris)
-		(void) strcpy(mtp->fsname, mp->mnt_special);
-#else
-		(void) strcpy(mtp->fsname, mp->mnt_fsname);
-#endif
+	    if (!(mtp = (struct mounts *)malloc(sizeof(struct mounts)))) {
+		err = 1;
+		break;
+	    }
 
 #if	defined(HASFSTYPE)
-		if ((mtp->fstype =
-			(char *)malloc((MALLOC_S)(strlen(sb.st_fstype) + 1)))
-		== NULL) {
-			err = 1;
-			break;
-		}
-		(void) strcpy(mtp->fstype, sb.st_fstype);
-#endif	/* HASFSTYPE */
+	    if (!(mtp->fstype = mkstrcpy(sb.st_fstype, (MALLOC_S *)NULL))) {
+		err = 1;
+		break;
+	    }
+#endif	/* defined(HASFSTYPE) */
 
-		mtp->dir = dn;
-		dn = NULL;
-		mtp->next = Mtab;
-		mtp->dev = sb.st_dev;
-		mtp->rdev = sb.st_rdev;
-		mtp->inode = sb.st_ino;
-		mtp->mode = sb.st_mode;
+	    mtp->dir = dn;
+	    dn = (char *)NULL;
+	    mtp->next = Mtab;
+	    mtp->dev = sb.st_dev;
+	    mtp->rdev = sb.st_rdev;
+	    mtp->inode = sb.st_ino;
+	    mtp->mode = sb.st_mode;
 
 #if	defined(HASPROCFS)
 
-		if (strcmp(sb.st_fstype, HASPROCFS) == 0) {
+	    if (strcmp(sb.st_fstype, HASPROCFS) == 0) {
 
-		/*
-		 * Save information on exactly on proc file system.
-		 */
-			if (procfs)
-				Mtprocfs = NULL;
-			else {
-				procfs = 1;
-				Mtprocfs = mtp;
-			}
+	    /*
+	     * Save information on exactly on proc file system.
+	     */
+		if (procfs)
+		    Mtprocfs = (struct mounts *)NULL;
+		else {
+		    procfs = 1;
+		    Mtprocfs = mtp;
 		}
-#endif
+	    }
+#endif	/* defined(HASPROCFS) */
 
-		Mtab = mtp;
+	/*
+	 * Interpolate a possible file system (mounted-on) device name link.
+	 */
+	    if (!(dn = mkstrcpy(
+
+#if	defined(solaris)
+				mp->mnt_special,
+#else	/* !defined(solaris) */
+				mp->mnt_fsname,
+#endif	/* defined(solaris) */
+
+				(MALLOC_S *)NULL)))
+
+	    {
+		err = 1;
+		break;
+	    }
+	    mtp->fsname = dn;
+	    ln = Readlink(dn);
+	    dn = (char *)NULL;
+	/*
+	 * Stat() the file system (mounted-on) name and add file system
+	 * information to the local mount table entry.
+	 */
+	    if (!ln || statsafely(ln, &sb))
+		sb.st_mode = 0;
+	    mtp->fsnmres = ln;
+	    mtp->fs_mode = sb.st_mode;
+	    Mtab = mtp;
         }
 
 #if	defined(solaris)
 	(void) fclose(mfp);
-#else
+#else	/* !defined(solaris) */
         (void) endmntent(mfp);
-#endif
+#endif	/* defined(solaris) */
 
-	if (dn)
-		(void) free((FREE_P *)dn);
 /*
  * Handle errors.
  */
+	if (dn)
+	    (void) free((FREE_P *)dn);
 	switch (err) {
 	case 1:
-		(void) fprintf(stderr, "%s: no space for mount at %s (%s)\n",
+	    (void) fprintf(stderr, "%s: no space for mount ", Pn);
 
 #if	defined(solaris)
-			Pn, mp->mnt_special, mp->mnt_mountp);
-#else
-			Pn, mp->mnt_fsname, mp->mnt_dir);
-#endif
+	    safestrprt(mp->mnt_special, stderr, 0);
+	    (void) fprintf(stderr, " (");
+	    safestrprt(mp->mnt_mountp, stderr, 0);
+#else	/* !defined(solaris) */
+	    safestrprt(mp->mnt_fsname, stderr, 0);
+	    (void) fprintf(stderr, " (");
+	    safestrprt(mp->mnt_dir, stderr, 0);
+#endif	/* defined(solaris) */
 
-		return(0);
+	    (void) fprintf(stderr, ")\n");
+	    return(0);
 	case 2:
-		return(1);
+	    return(1);
 	}
 	return(1);
 }
@@ -364,7 +369,7 @@ readmnt()
 
 struct l_vfs *
 readvfs(ka, la, lv)
-	struct vfs *ka;			/* vfs structure kernel address, if
+	KA_T ka;			/* vfs structure kernel address, if
 					 * must be read from kernel */
 	struct vfs *la;			/* local vfs structure address, non-
 					 * NULL if already read from kernel */
@@ -376,21 +381,21 @@ readvfs(ka, la, lv)
 #if	!defined(solaris)
 	struct mount m;
 	dev_t td;
-# endif
+# endif	/* !defined(solaris) */
 
 	if (!ka && !la)
-		return(NULL);
+	    return((struct l_vfs *)NULL);
 	for (vp = Lvfs; vp; vp = vp->next) {
-		if (ka == vp->addr)
-			return(vp);
+	    if (ka == vp->addr)
+		return(vp);
 	}
-	if ((vp = (struct l_vfs *)malloc(sizeof(struct l_vfs))) == NULL) {
-		(void) fprintf(stderr, "%s: PID %d, no space for vfs\n",
-			Pn, Lp->pid);
-		Exit(1);
+	if (!(vp = (struct l_vfs *)malloc(sizeof(struct l_vfs)))) {
+	    (void) fprintf(stderr, "%s: PID %d, no space for vfs\n",
+		Pn, Lp->pid);
+	    Exit(1);
 	}
-	vp->dir = NULL;
-	vp->fsname = NULL;
+	vp->dir = (char *)NULL;
+	vp->fsname = (char *)NULL;
 
 #if	defined(HASFSINO)
 	vp->fs_ino = 0;
@@ -400,13 +405,13 @@ readvfs(ka, la, lv)
  * Read vfs structure from kernel, if necessary.
  */
 	if (la)
-		v = la;
+	    v = la;
 	else {
-		v = &tv;
-		if (kread((KA_T)ka, (char *)v, sizeof(tv))) {
-			(void) free((FREE_P *)vp);
-			return(NULL);
-		}
+	    v = &tv;
+	    if (kread((KA_T)ka, (char *)v, sizeof(tv))) {
+		(void) free((FREE_P *)vp);
+		return((struct l_vfs *)NULL);
+	    }
 	}
 
 #if	defined(HAS_AFS)
@@ -415,7 +420,7 @@ readvfs(ka, la, lv)
  */
 # if	defined(solaris)
 	if (v->vfs_fstype == AFSfstype)
-		v->vfs_dev = AFSDEV;
+	    v->vfs_dev = AFSDEV;
 # endif	/* defined(solaris) */
 #endif	/* defined(HAS_AFS) */
 
@@ -425,32 +430,24 @@ readvfs(ka, la, lv)
 
 #if	defined(solaris)
 	(void) completevfs(vp, (dev_t *)&v->vfs_dev);
-#else
+#else	/* !defined(solaris) */
 	if (Ntype == N_HSFS || Ntype == N_PCFS) {
-		td = (dev_t)(v->vfs_fsid.val[0] & 0xffff);
-		(void) completevfs(vp, &td);
+	    td = (dev_t)(v->vfs_fsid.val[0] & 0xffff);
+	    (void) completevfs(vp, &td);
 	} else if (v->vfs_data) {
-	       if (kread((KA_T)v->vfs_data, (char *)&m, sizeof(m)) == 0)
-			(void) completevfs(vp, &m.m_dev);
+	    if (!kread((KA_T)v->vfs_data, (char *)&m, sizeof(m)))
+		(void) completevfs(vp, &m.m_dev);
 	}
 # if	defined(HAS_AFS)
 	else if (!lv->v_data && AFSVfsp && lv->v_vfsp == AFSVfsp) {
-		td = (dev_t)AFSDEV;
-		(void) completevfs(vp, &td);
+	    td = (dev_t)AFSDEV;
+	    (void) completevfs(vp, &td);
 	}
 # endif	/* defined(HAS_AFS) */
-#endif	/* solaris */
+#endif	/* defined(solaris) */
 
 	vp->next = Lvfs;
 	vp->addr = ka;
 	Lvfs = vp;
 	return(vp);
 }
-
-
-/*
- * The completevfs() function is obtained from ../common/cvfs.frag.
- */
-
-#define	CVFS_DEVSAVE 	1
-#define	USECVFS		1
