@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dstore.c,v 1.12 96/03/26 15:22:07 abe Exp $";
+static char *rcsid = "$Id: dstore.c,v 1.3 98/03/06 19:21:24 abe Exp $";
 #endif
 
 
@@ -53,20 +53,84 @@ char *AFSApath = (char *)NULL;		/* alternate AFS name list path
 #if	defined(solaris)
 int AFSfstype = -1;			/* AFS file system type index */
 # endif	/* defined(solaris) */
-struct vfs *AFSVfsp = (struct vfs *)NULL;
-					/* AFS vfs struct kernel address */
+
+KA_T AFSVfsp = (KA_T)NULL;		/* AFS vfs struct kernel address */
 #endif	/* defined(HAS_AFS) */
 
 struct clone *Clone = NULL;		/* clone list */
 
 #if	defined(solaris)
-int CloneMaj;				/* clone major device number */
+major_t CloneMaj;			/* clone major device number */
 #endif	/* defined(solaris) */
 
 #if	!defined(solaris)
 char *Cwd = NULL;			/* cwd path name buffer */
+struct file *Fileptr;			/* for process_file() in dfile.c */
 #endif
 
+
+/*
+ * Drive_Nl -- table to drive the building of Nl[] via build_Nl()
+ *	       (See lsof.h and misc.c.)
+ */
+
+struct drive_Nl Drive_Nl[] = {
+
+# if	defined(solaris)
+	{ "arFid",	"afs_rootFid"		},
+	{ "avops",	"afs_vnodeops"		},
+	{ "avol",	"afs_volumes"		},
+	{ "auvops",	"auto_vnodeops"		},
+	{ "cvops",	"cachefs_vnodeops"	},
+	{ "clmaj",	"clonemaj"		},
+	{ "fvops",	"fifo_vnodeops"		},
+	{ "hvops",	"hsfs_vnodeops"		},
+	{ "lvops",	"lo_vnodeops"		},
+	{ "mvops",	"mvfs_vnodeops"		},
+	{ X_NCACHE,	"ncache"		},
+	{ X_NCSIZE,	"ncsize"		},
+	{ "nvops",	"nfs_vnodeops"		},
+	{ "n3vops",	"nfs3_vnodeops"		},
+	{ "nmvops",	"nm_vnodeops"		},
+        { "nproc",	"nproc"			},
+	{ "pdvops",	"pcfs_dvnodeops"	},
+	{ "pfvops",	"pcfs_fvnodeops"	},
+	{ "prvops",	"prvnodeops"		},
+	{ "sgvops",	"segvn_ops"		},
+	{ "sckvops",	"sock_vnodeops"		},
+	{ "spvops",	"spec_vnodeops"		},
+	{ "tvops",	"tmp_vnodeops"		},
+	{ "uvops",	"ufs_vnodeops"		},
+	{ "vvops",	"vx_vnodeops"		},
+
+# if	solaris>=20500
+	{ "dvops",	"door_vnodeops"		},
+	{ "kbase",	"_kernelbase"		},
+# endif	/* solaris>=20500 */
+
+# else	/* !defined(solaris) */
+	{ "arFid",	"_afs_rootFid"		},
+	{ "avops",	"_afs_vnodeops"		},
+	{ "avol",	"_afs_volumes"		},
+	{ "fvops",	"_fifo_vnodeops"	},
+        { "hvops",	"_hsfs_vnodeops"	},
+	{ X_NCACHE,	"_ncache"		},
+	{ X_NCSIZE,	"_ncsize"		},
+        { "nvops",	"_nfs_vnodeops"		},
+        { "n3vops",	"_nfs3_vnodeops"	},
+        { "nproc",	"_nproc"		},
+	{ "pdvops",	"_pcfs_dvnodeops"	},
+	{ "pfvops",	"_pcfs_fvnodeops"	},
+	{ "sgvops",	"_segvn_ops"		},
+	{ "spvops",	"_spec_vnodeops"	},
+	{ "tvops",	"_tmp_vnodeops"		},
+	{ "uvops",	"_ufs_vnodeops"		},
+# endif	/* defined(solaris) */
+
+	{ "",		""			},
+	{ NULL,		NULL			}
+};
+
 #if	defined(solaris)
 char **Fsinfo = NULL;			/* file system information */
 int Fsinfomax = 0;			/* maximum file system type */
@@ -86,59 +150,6 @@ struct netclone *Netclone = NULL;	/* net clone devices from
 					 * /devices/pseudo */
 # endif
 
-struct nlist Nl[] = {
-
-# if	defined(solaris)
-	{ "afs_rootFid"		},
-	{ "afs_vnodeops"	},
-	{ "afs_volumes"		},
-	{ "cachefs_vnodeops"	},
-	{ "clonemaj"		},
-	{ "fifo_vnodeops"	},
-	{ "hsfs_vnodeops"	},
-	{ "lo_vnodeops"		},
-	{ "mvfs_vnodeops"	},
-	{ "ncache"		},
-	{ "ncsize"		},
-	{ "nfs_vnodeops"	},
-	{ "nfs3_vnodeops"	},
-	{ "nm_vnodeops"		},
-        { "nproc"		},
-	{ "pcfs_dvnodeops"	},
-	{ "pcfs_fvnodeops"	},
-	{ "prvnodeops"		},
-	{ "segvn_ops"		},
-	{ "spec_vnodeops"	},
-	{ "tmp_vnodeops"	},
-	{ "ufs_vnodeops"	},
-
-# if	solaris>=20500
-	{ "door_vnodeops"	},
-	{ "_kernelbase"		},
-# endif	/* solaris>=20500 */
-
-# else	/* !defined(solaris) */
-	{ "_afs_rootFid"	},
-	{ "_afs_vnodeops"	},
-	{ "_afs_volumes"	},
-	{ "_fifo_vnodeops"	},
-        { "_hsfs_vnodeops"	},
-	{ "_ncache"		},
-	{ "_ncsize"		},
-        { "_nfs_vnodeops"	},
-        { "_nfs3_vnodeops"	},
-        { "_nproc"		},
-	{ "_pcfs_dvnodeops"	},
-	{ "_pcfs_fvnodeops"	},
-	{ "_segvn_ops"		},
-	{ "_spec_vnodeops"	},
-	{ "_tmp_vnodeops"	},
-	{ "_ufs_vnodeops"	},
-# endif	/* defined(solaris) */
-
-	{ "" }
-};
-
 #if	defined(solaris)
 struct pseudo *Pseudo = NULL;		/* non-clone devices from
 					 * /devices/pseudo */
