@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: proto.h,v 1.21 96/04/05 10:02:46 abe Exp $
+ * $Id: proto.h,v 1.10 98/03/09 12:58:30 abe Exp $
  */
 
 
@@ -44,14 +44,30 @@
 
 #if	defined(__STDC__)
 #define	_PROTOTYPE(function, params)	function params
-#else
+#else	/* !defined(__STDC__) */
 #define	_PROTOTYPE(function, params)	function()
 #endif /* defined(__STDC__) */
 
 
+/*
+ * The following define keeps gcc>=2.7 from complaining about the failure
+ * of the Exit() function to return.
+ *
+ * Paul Eggert <eggert@twinsun.com> supplied it.
+ */
+
+#if	defined(__GNUC__) && !(__GNUC__<2 || (__GNUC__==2 && __GNUC_MINOR__<7))
+#define	exiting	__attribute__((__noreturn__))
+#else	/* !gcc || gcc<2.7 */
+#define	exiting
+#endif	/* gcc && gcc>=2.7 */
+
+
 _PROTOTYPE(extern void alloc_lfile,(char *nm, int num));
-_PROTOTYPE(extern void alloc_lproc,(int pid, int pgrp, UID_ARG uid, char *cmd, int pss, int sf));
+_PROTOTYPE(extern void alloc_lproc,(int pid, int pgrp, int ppid, UID_ARG uid, char *cmd, int pss, int sf));
+_PROTOTYPE(extern void childx,(void));
 _PROTOTYPE(extern int ck_file_arg,(int i, int ac, char *av[]));
+_PROTOTYPE(extern void clr_devtab,(void));
 _PROTOTYPE(extern int compdev,(COMP_P *a1, COMP_P *a2));
 _PROTOTYPE(extern int comppid,(COMP_P *a1, COMP_P *a2));
 
@@ -59,7 +75,6 @@ _PROTOTYPE(extern int comppid,(COMP_P *a1, COMP_P *a2));
 _PROTOTYPE(extern void dropgid,(void));
 #endif	/* defined(WILLDROPGID) */
 
-_PROTOTYPE(extern void childx,(void));
 _PROTOTYPE(extern char *endnm,(void));
 _PROTOTYPE(extern void enter_dev_ch,(char *m));
 _PROTOTYPE(extern int enter_fd,(char *f));
@@ -69,42 +84,57 @@ _PROTOTYPE(extern void enter_nm,(char *m));
 _PROTOTYPE(extern int enter_str_lst,(char *opt, char *s, struct str_lst **lp));
 _PROTOTYPE(extern int enter_uid,(char *u));
 _PROTOTYPE(extern int examine_lproc,(void));
-_PROTOTYPE(extern void Exit,(int xv));
+_PROTOTYPE(extern void ent_inaddr,(struct in_addr *la, int lp, struct in_addr *fa, int fp));
+_PROTOTYPE(extern void Exit,(int xv)) exiting;
 _PROTOTYPE(extern void find_ch_ino,(void));
+_PROTOTYPE(extern void free_lproc,(struct lproc *lp));
 _PROTOTYPE(extern void gather_proc_info,(void));
 _PROTOTYPE(extern char *gethostnm,(struct in_addr *ia));
 _PROTOTYPE(extern void initialize,(void));
-_PROTOTYPE(extern void iporttab,(void));
 _PROTOTYPE(extern int is_cmd_excl,(char *cmd, short *pss, short *sf));
 _PROTOTYPE(extern int is_file_sel,(struct lfile *lf));
 _PROTOTYPE(extern int is_nw_addr,(struct in_addr *ia, int p));
 _PROTOTYPE(extern int is_proc_excl,(int pid, int pgrp, UID_ARG uid, short *pss, short *sf));
 _PROTOTYPE(extern int is_readable,(char *path, int msg));
-_PROTOTYPE(extern void iuidcache,(int np));
 _PROTOTYPE(extern int kread,(KA_T addr, char *buf, READLEN_T len));
 _PROTOTYPE(extern void link_lfile,(void));
-_PROTOTYPE(extern struct l_dev *lkupdev,(dev_t *dev, int i));
+_PROTOTYPE(extern struct l_dev *lkupdev,(dev_t *dev, int i, int r));
 _PROTOTYPE(extern int main,(int argc, char *argv[]));
+_PROTOTYPE(extern char *mkstrcpy,(char *src, MALLOC_S *rlp));
+_PROTOTYPE(extern char *mkstrcat,(char *s1, int l1, char *s2, int l2, char *s3, int l3, MALLOC_S *clp));
 _PROTOTYPE(extern int printchdevname,(dev_t *rdev, int f));
 _PROTOTYPE(extern void print_file,(void));
-_PROTOTYPE(extern void printinaddr,(struct in_addr *ia, int p));
+_PROTOTYPE(extern void print_init,(void));
 _PROTOTYPE(extern void printiproto,(int p));
 _PROTOTYPE(extern void printname,(int nl));
+_PROTOTYPE(extern char *print_kptr,(KA_T kp, char *buf));
 _PROTOTYPE(extern void print_proc,(void));
 _PROTOTYPE(extern void printrawaddr,(struct sockaddr *sa));
+_PROTOTYPE(extern void print_tcptpi,(int nl));
 _PROTOTYPE(extern char *printuid,(UID_ARG u, int *ty));
 _PROTOTYPE(extern void printunkaf,(int fam));
-_PROTOTYPE(extern void process_file,(struct file *fp));
-_PROTOTYPE(extern void process_node,(caddr_t f));
+_PROTOTYPE(extern void process_file,(KA_T fp));
+_PROTOTYPE(extern void process_node,(KA_T f));
 _PROTOTYPE(extern char *Readlink,(char *arg));
-_PROTOTYPE(extern void readdev,(void));
+_PROTOTYPE(extern void readdev,(int skip));
 _PROTOTYPE(extern int readmnt,(void));
+_PROTOTYPE(extern void rereaddev,(void));
+_PROTOTYPE(extern int safestrlen,(char *sp, int flags));
+_PROTOTYPE(extern void safestrprtn,(char *sp, int len, FILE *fs, int flags));
+_PROTOTYPE(extern void safestrprt,(char *sp, FILE *fs, int flags));
 _PROTOTYPE(extern int statsafely,(char *path, struct stat *buf));
 _PROTOTYPE(extern void usage,(int xv, int fh, int version));
+_PROTOTYPE(extern int vfy_dev,(struct l_dev *dp));
 _PROTOTYPE(extern char *x2dev,(char *s, dev_t *d));
 
+#if	defined(HASBLKDEV)
+_PROTOTYPE(extern void find_bl_ino,(void));
+_PROTOTYPE(extern struct l_dev *lkupbdev,(dev_t *dev, int i, int r));
+_PROTOTYPE(extern int printbdevname,(dev_t *rdev, int f));
+#endif	/* defined(HASBLKDEV) */
+
 #if	defined(HASCDRNODE)
-_PROTOTYPE(extern int readcdrnode,(caddr_t ca, struct cdrnode *c));
+_PROTOTYPE(extern int readcdrnode,(KA_T ca, struct cdrnode *c));
 #endif	/* defined(HASCDRNODE) */
 
 #if	defined(HASDCACHE)
@@ -120,49 +150,79 @@ _PROTOTYPE(extern void write_dcache,(void));
 #endif	/* defined(HASDCACHE) */
 
 #if	defined(HASFIFONODE)
-_PROTOTYPE(extern int readfifonode,(caddr_t fa, struct fifonode *f));
+_PROTOTYPE(extern int readfifonode,(KA_T fa, struct fifonode *f));
 #endif	/* defined(HASFIFONODE) */
 
 #if	defined(HASGNODE)
-_PROTOTYPE(extern int readgnode,(caddr_t ga, struct gnode *g));
+_PROTOTYPE(extern int readgnode,(KA_T ga, struct gnode *g));
 #endif	/* defined(HASGNODE) */
 
 #if	defined(HASHSNODE)
-_PROTOTYPE(extern int readhsnode,(caddr_t ha, struct hsnode *h));
+_PROTOTYPE(extern int readhsnode,(KA_T ha, struct hsnode *h));
 #endif	/* defined(HASHSNODE) */
 
 #if	defined(HASINODE)
-_PROTOTYPE(extern int readinode,(struct inode *ia, struct inode *i));
+_PROTOTYPE(extern int readinode,(KA_T ia, struct inode *i));
 #endif	/* defined(HASINODE) */
 
 #if	defined(HASNCACHE)
+_PROTOTYPE(extern void ncache_load,(void));
 _PROTOTYPE(extern char *ncache_lookup,(char *buf, int blen, int *fp));
 #endif	/* defined(HASNCACHE) */
 
+#if	defined(HASNLIST)
+_PROTOTYPE(extern void build_Nl,(struct drive_Nl *d));
+_PROTOTYPE(extern int get_Nl_value,(char *nn, struct drive_Nl *d, KA_T *v));
+#endif	/* defined(HASNLIST) */
+
 #if	defined(HASPIPENODE)
-_PROTOTYPE(extern int readpipenode,(caddr_t pa, struct pipenode *p));
+_PROTOTYPE(extern int readpipenode,(KA_T pa, struct pipenode *p));
 #endif	/* defined(HASPIPENODE) */
 
+#if	defined(HASPRINTDEV)
+_PROTOTYPE(extern char *HASPRINTDEV,(struct lfile *lf));
+#endif	/* defined(HASPRINTDEV) */
+
+#if	defined(HASPRINTINO)
+_PROTOTYPE(extern char *HASPRINTINO,(struct lfile *lf));
+#endif	/* defined(HASPRINTINO) */
+
+#if	defined(HASPRINTNM)
+_PROTOTYPE(extern void HASPRINTNM,(struct lfile *lf));
+#endif	/* defined(HASPRINTNM) */
+
+#if	defined(HASPRIVNMCACHE)
+_PROTOTYPE(extern int HASPRIVNMCACHE,(struct lfile *lf));
+#endif	/* defined(HASPRIVNMCACHE) */
+
+#if	defined(HASPRINTOFF)
+_PROTOTYPE(extern char *HASPRINTOFF,(struct lfile *lf, int ty));
+#endif	/* defined(HASPRINTOFF) */
+
+#if	defined(HASPRINTSZ)
+_PROTOTYPE(extern char *HASPRINTSZ,(struct lfile *lf));
+#endif	/* defined(HASPRINTSZ) */
+
 #if	defined(HASRNODE)
-_PROTOTYPE(extern int readrnode,(caddr_t ra, struct rnode *r));
+_PROTOTYPE(extern int readrnode,(KA_T ra, struct rnode *r));
 #endif	/* defined(HASRNODE) */
 
 #if	defined(HASSNODE)
-_PROTOTYPE(extern int readsnode,(caddr_t sa, struct snode *s));
+_PROTOTYPE(extern int readsnode,(KA_T sa, struct snode *s));
 #endif	/* defined(HASSNODE) */
 
 #if	defined(HASSTREAMS)
-_PROTOTYPE(extern int readstdata,(struct stdata *addr, struct stdata *buf));
-_PROTOTYPE(extern int readsthead,(struct queue *addr, struct queue *buf));
-_PROTOTYPE(extern int readstidnm,(char *addr, char *buf, READLEN_T len));
-_PROTOTYPE(extern int readstmin,(struct module_info *addr, struct module_info *buf));
-_PROTOTYPE(extern int readstqinit,(struct qinit *addr, struct qinit *buf));
+_PROTOTYPE(extern int readstdata,(KA_T addr, struct stdata *buf));
+_PROTOTYPE(extern int readsthead,(KA_T addr, struct queue *buf));
+_PROTOTYPE(extern int readstidnm,(KA_T addr, char *buf, READLEN_T len));
+_PROTOTYPE(extern int readstmin,(KA_T addr, struct module_info *buf));
+_PROTOTYPE(extern int readstqinit,(KA_T addr, struct qinit *buf));
 #endif	/* defined(HASSTREAMS) */
 
 #if	defined(HASTMPNODE)
-_PROTOTYPE(extern int readtmpnode,(caddr_t tmpa, struct tmpnode *t));
+_PROTOTYPE(extern int readtnode,(KA_T ta, struct tmpnode *t));
 #endif	/* defined(HASTMPNODE) */
 
 #if	defined(HASVNODE)
-_PROTOTYPE(extern int readvnode,(caddr_t va, struct vnode *v));
+_PROTOTYPE(extern int readvnode,(KA_T va, struct vnode *v));
 #endif	/* defined(HASVNODE) */
